==> OB-3.1.2.tar.gz: OB-3.1.2/ob/src/translator/GenUtil.h <==
// **********************************************************************
//
// Copyright (c) 1997
// Object-Oriented Concepts, Inc.
// Billerica, MA, USA
//
// All Rights Reserved
//
// **********************************************************************

#ifndef GEN_UTIL_H
#define GEN_UTIL_H

//
// The "Pretty-Print" class
//
class IdlPrettyPrint
{
    ostream& out_;

    unsigned int _ob_num_;

protected:

    unsigned int indent_;
    unsigned int pos_;

    bool ignoreNextSep_;

    //
    // Newline with indent
    //
    virtual void nl();

public:

    IdlPrettyPrint(ostream& out, unsigned int num = 4)
	: out_(out), _ob_num_(num), indent_(0), pos_(0),
	  ignoreNextSep_(false) { }
    virtual ~IdlPrettyPrint() { }

    //
    // Set and get indent
    //
    void setIndent(unsigned int in) { indent_ = in; }
    unsigned int getIndent() const { return indent_; }

    //
    // Get and set output position
    //
    unsigned int getPos() const { return pos_; }
    void setPos(unsigned int pos) { pos_ = pos; };

    //
    // Print directly, without character interpretation
    //
    void direct(char c) { out_ << c; }
    void direct(const char* s) { out_ << s; }

    //
    // Increment and decrement indent
    //
    void inc() { indent_ += _ob_num_; }
    void dec() { assert(indent_ >= _ob_num_); indent_ -= _ob_num_; }

    //
    // Block start and end
    //
    virtual void start();
    virtual void end();

    //
    // Separator
    //
    virtual void sep();
    virtual void ignoreNextSep(bool);

    //
    // Print
    //
    virtual void printChar(char);
    virtual void printString(const char*);
};

//
// Output operators
//
IdlPrettyPrint& operator<<(IdlPrettyPrint&, char);
IdlPrettyPrint& operator<<(IdlPrettyPrint&, const char*);
IdlPrettyPrint& operator<<(IdlPrettyPrint&, short);
IdlPrettyPrint& operator<<(IdlPrettyPrint&, int);
IdlPrettyPrint& operator<<(IdlPrettyPrint&, long);
IdlPrettyPrint& operator<<(IdlPrettyPrint&, unsigned short);
IdlPrettyPrint& operator<<(IdlPrettyPrint&, unsigned int);
IdlPrettyPrint& operator<<(IdlPrettyPrint&, unsigned long);
IdlPrettyPrint& operator<<(IdlPrettyPrint&, float);
IdlPrettyPrint& operator<<(IdlPrettyPrint&, double);

//
// Remove scope from absolute name
//
void IdlRemoveScope(const char*, char*&);

//
// Get anonymous name from template name
//
char* IdlGetAnonName(const char*);

//
// Get original type, i.e. translate aliases to the real type
//
CORBA_IDLType_ptr IdlGetOrigIDLType(CORBA_IDLType_ptr);

//
// Check for variable size type
//
bool IdlIsVariable(CORBA_TypeCode_ptr);

//
// Get TypeCode converted to ASCII
// Output TypeCode converted to ASCII
//
char* IdlGetAsciiTypeCode(CORBA_TypeCode_ptr);
void IdlOutputAsciiTypeCode(CORBA_TypeCode_ptr, IdlPrettyPrint&);

//
// Convert path name to identifier
//
char* IdlPathToIdent(const char*);

//
// Check if union has an implicit default
//
bool IdlImplicitUnionDefault(CORBA_TypeCode_ptr);

//
// Get union info
//
IdlUnionMemberInfoSeq* IdlGetUnionInfo(CORBA_TypeCode_ptr);

//
// Create sequence with all base interfaces
//
void IdlGetAllBaseInterfaces(CORBA_InterfaceDef_ptr, CORBA_InterfaceDefSeq&);

//
// Get all method names
//
IdlStringSeq* IdlGetMethodNames(const CORBA_ContainedSeq&,
				const CORBA_ContainedSeq&);
#endif

==> OB-4.0a2.tar.gz: OB-4.0a2/ob/src/translator/GenUtil.h <==
// **********************************************************************
//
// Copyright (c) 1997
// Object-Oriented Concepts, Inc.
// Billerica, MA, USA
//
// All Rights Reserved
//
// **********************************************************************

#ifndef GEN_UTIL_H
#define GEN_UTIL_H

//
// The "Pretty-Print" class
//
class IdlPrettyPrint
{
    OB_STD(ostream)& out_;

    unsigned int _ob_num_;

protected:

    unsigned int indent_;
    unsigned int pos_;

    bool ignoreNextSep_;

    //
    // Newline with indent
    //
    virtual void nl();

public:

    IdlPrettyPrint(OB_STD(ostream)& out, unsigned int num = 4)
	: out_(out), _ob_num_(num), indent_(0), pos_(0),
	  ignoreNextSep_(false) { }
    virtual ~IdlPrettyPrint() { }

    //
    // Set and get indent
    //
    void setIndent(unsigned int in) { indent_ = in; }
    unsigned int getIndent() const { return indent_; }

    //
    // Get and set output position
    //
    unsigned int getPos() const { return pos_; }
    void setPos(unsigned int pos) { pos_ = pos; };

    //
    // Print directly, without character interpretation
    //
    void direct(char c) { out_ << c; }
    void direct(const char* s) { out_ << s; }

    //
    // Increment and decrement indent
    //
    void inc() { indent_ += _ob_num_; }
    void dec() { assert(indent_ >= _ob_num_); indent_ -= _ob_num_; }

    //
    // Block start and end
    //
    virtual void start();
    virtual void end();

    //
    // Separator
    //
    virtual void sep();
    virtual void ignoreNextSep(bool);

    //
    // Print
    //
    virtual void printChar(char);
    virtual void printWChar(wchar_t);
    virtual void printString(const char*);
    virtual void printWString(const wchar_t*);
};

//
// Output operators
//
IdlPrettyPrint& operator<<(IdlPrettyPrint&, char);
#ifndef HAVE_WIN32_WCHAR_TYPE
IdlPrettyPrint& operator<<(IdlPrettyPrint&, wchar_t);
#endif
IdlPrettyPrint& operator<<(IdlPrettyPrint&, const char*);
IdlPrettyPrint& operator<<(IdlPrettyPrint&, const wchar_t*);
IdlPrettyPrint& operator<<(IdlPrettyPrint&, short);
IdlPrettyPrint& operator<<(IdlPrettyPrint&, int);
IdlPrettyPrint& operator<<(IdlPrettyPrint&, long);
IdlPrettyPrint& operator<<(IdlPrettyPrint&, CORBA::LongLong);
IdlPrettyPrint& operator<<(IdlPrettyPrint&, unsigned short);
IdlPrettyPrint& operator<<(IdlPrettyPrint&, unsigned int);
IdlPrettyPrint& operator<<(IdlPrettyPrint&, unsigned long);
IdlPrettyPrint& operator<<(IdlPrettyPrint&, CORBA::ULongLong);
IdlPrettyPrint& operator<<(IdlPrettyPrint&, float);
IdlPrettyPrint& operator<<(IdlPrettyPrint&, double);
IdlPrettyPrint& operator<<(IdlPrettyPrint&, CORBA::LongDouble);

//
// Remove scope from absolute name
//
void IdlRemoveScope(const char*, char*&);

//
// Get original type, i.e. translate aliases to the real type
//
CORBA::IDLType_ptr IdlGetOrigIDLType(CORBA::IDLType_ptr);

//
// Check for variable size type
//
bool IdlIsVariable(CORBA::TypeCode_ptr);

//
// Get TypeCode converted to ASCII
// Output TypeCode converted to ASCII
//
char* IdlGetAsciiTypeCode(CORBA::TypeCode_ptr);
void IdlOutputAsciiTypeCode(CORBA::TypeCode_ptr, IdlPrettyPrint&);

//
// Convert path name to identifier
//
char* IdlPathToIdent(const char*);

//
// Check if union has an implicit default
//
bool IdlImplicitUnionDefault(CORBA::TypeCode_ptr);

//
// Get union info
//
IdlUnionMemberInfoSeq* IdlGetUnionInfo(CORBA::TypeCode_ptr);

//
// Create sequence with all base interfaces
//
void IdlGetAllBaseInterfaces(CORBA::InterfaceDef_ptr, CORBA::InterfaceDefSeq&);

//
// Create sequence with information about base interfaces
//
void IdlGetBaseInterfaces(CORBA::InterfaceDef_ptr, IdlBaseInterfaceInfoSeq&,
                          bool);

//
// Create sequence with all base values
//
void IdlGetAllBaseValues(CORBA::ValueDef_ptr, CORBA::ValueDefSeq&);

//
// Create sequence with all truncatable base values
//
void IdlGetAllTruncatableBaseValues(CORBA::ValueDef_ptr, CORBA::ValueDefSeq&);

//
// Create sequence with all value members, including all inherited members,
// in the proper marshalling order (i.e., from top to bottom)
//
void IdlGetAllValueMembers(CORBA::ValueDef_ptr, CORBA::ValueMemberSeq&);

//
// Get all method names
//
IdlStringSeq* IdlGetMethodNames(const CORBA::ContainedSeq&,
                                const CORBA::ContainedSeq&);

#endif
